==> aws-java-sdk-bundle-1.11.230-sources.jar: com/amazonaws/services/sqs/internal/RequestCopyUtils.java <==
/*
 * Copyright 2011-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at:
 *
 *    http://aws.amazon.com/apache2.0
 *
 * This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES
 * OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and
 * limitations under the License.
 */
package com.amazonaws.services.sqs.internal;

import com.amazonaws.annotation.SdkInternalApi;
import com.amazonaws.services.sqs.model.SendMessageBatchRequestEntry;
import com.amazonaws.services.sqs.model.SendMessageRequest;

@SdkInternalApi
public class RequestCopyUtils {

    /**
     * Creates a #SendMessageBatchRequestEntry object from a id and #SendMessageRequest object.
     * The common members of {@link SendMessageRequest} object are copied to the
     * returned {@link SendMessageBatchRequestEntry} object.
     */
    public static SendMessageBatchRequestEntry createSendMessageBatchRequestEntryFrom(String id,
                                                                                      SendMessageRequest sendMessageRequest) {
        return new SendMessageBatchRequestEntry()
                .withId(id)
                .withMessageBody(sendMessageRequest.getMessageBody())
                .withDelaySeconds(sendMessageRequest.getDelaySeconds())
                .withMessageAttributes(sendMessageRequest.getMessageAttributes())
                .withMessageDeduplicationId(sendMessageRequest.getMessageDeduplicationId())
                .withMessageGroupId(sendMessageRequest.getMessageGroupId());
    }
}

==> aws-java-sdk-bundle-1.11.1034-sources.jar: com/amazonaws/services/sqs/internal/RequestCopyUtils.java <==
/*
 * Copyright 2011-2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at:
 *
 *    http://aws.amazon.com/apache2.0
 *
 * This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES
 * OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and
 * limitations under the License.
 */
package com.amazonaws.services.sqs.internal;

import com.amazonaws.annotation.SdkInternalApi;
import com.amazonaws.services.sqs.model.SendMessageBatchRequestEntry;
import com.amazonaws.services.sqs.model.SendMessageRequest;

@SdkInternalApi
public class RequestCopyUtils {

    /**
     * Creates a #SendMessageBatchRequestEntry object from a id and #SendMessageRequest object.
     * The common members of {@link SendMessageRequest} object are copied to the
     * returned {@link SendMessageBatchRequestEntry} object.
     */
    public static SendMessageBatchRequestEntry createSendMessageBatchRequestEntryFrom(String id,
                                                                                      SendMessageRequest sendMessageRequest) {
        return new SendMessageBatchRequestEntry()
            .withId(id)
            .withMessageBody(sendMessageRequest.getMessageBody())
            .withDelaySeconds(sendMessageRequest.getDelaySeconds())
            .withMessageAttributes(sendMessageRequest.getMessageAttributes())
            .withMessageDeduplicationId(sendMessageRequest.getMessageDeduplicationId())
            .withMessageGroupId(sendMessageRequest.getMessageGroupId())
            .withMessageSystemAttributes(sendMessageRequest.getMessageSystemAttributes());
    }
}
